# eric7.MicroPython.MicroPythonWebreplConnectionDialog

Module implementing a dialog to enter the WebREPL connection parameters.

### Global Attributes

None

### Classes

MicroPythonWebreplConnectionDialog | Class implementing a dialog to enter the WebREPL connection parameters.

### Functions

None

## MicroPythonWebreplConnectionDialog

Class implementing a dialog to enter the WebREPL connection parameters.

### Derived from

QDialog, Ui_MicroPythonWebreplConnectionDialog

### Class Attributes

None

### Class Methods

None

### Methods

MicroPythonWebreplConnectionDialog | Constructor
__updateOkButton | Private slot to update the enabled state of the OK button.
getWebreplConnectionParameters | Public method to retrieve the entered WebREPL connection data.
on_showPasswordButton_clicked | Private slot to show or hide the password.

### Static Methods

None

#### MicroPythonWebreplConnectionDialog (Constructor)

MicroPythonWebreplConnectionDialog(currentWebreplUrl, currentType, parent=None)

Constructor

currentWebreplUrl (str)
  WebREPL URL most recently configured
currentType (str)
  device type most recently selected
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### MicroPythonWebreplConnectionDialog.__updateOkButton

__updateOkButton()

Private slot to update the enabled state of the OK button.

#### MicroPythonWebreplConnectionDialog.getWebreplConnectionParameters

getWebreplConnectionParameters()

Public method to retrieve the entered WebREPL connection data.

Return:
  tuple containing the URL and device type for the WebREPL connection

Return Type:
  tuple of (str, str)

#### MicroPythonWebreplConnectionDialog.on_showPasswordButton_clicked

on_showPasswordButton_clicked(checked)

Private slot to show or hide the password.

checked (bool)
  state of the button

Up